@@ -58,6 +58,7 @@ import Data.ByteString.Char8 ()
 import Data.Bits ((.&.), shiftR)
 import Data.Char (isAscii, isControl)
 import Data.Word (Word8)
+import Data.String (IsString(..))
 import qualified Data.ByteString as S
 import Data.Text (Text)
 import qualified Data.Text as T
@@ -121,6 +122,9 @@ data Address = Address
     }
   deriving (Eq, Show)
 
+instance IsString Address where
+    fromString = Address Nothing . Data.String.fromString
+
 -- | How to encode a single part. You should use 'Base64' for binary data.
 data Encoding = None | Base64 | QuotedPrintableText | QuotedPrintableBinary
   deriving (Eq, Show)
